plater: Read, Tidy, and Display Data from Microtiter Plates
Source:R/plater-package.R, R/plater.R
plater-package.RdTools for interacting with data from experiments done in microtiter plates. Easily read in plate-shaped data and convert it to tidy format, combine plate-shaped data with tidy data, and view tidy data in plate shape.
plater defines a simple, plate-shaped file format for data storage, so it's
easy to remember the experimental design. The package provides functions to
seamlessly convert between that format and a tidy data frame that's optimal
for analysis. check_plater_format is provided to help
you manage plate-shaped files.
You can work with purely plate-shaped
data (read_plate and
read_plates), as well as with a combination of
plate-shaped data and tidy data (add_plate). It further
allows easy plate-shaped visualization of tidy data
(view_plate).
See also
Author
Maintainer: Sean Hughes smhughes@uw.edu (ORCID)